.. _image_manipulation:

========================================
Manipulation brain volumes with nilearn
========================================

In this section, we detail the general tools to manipulate of
brain images with nilearn.

|

.. toctree::

   input_output.rst
   manipulating_images.rst
   masker_objects.rst
